@@ -24,8 +24,8 @@ pref("browser.search.param.yahoo-fr", "linuxmint");
 
 // Set the UserAgent
 pref("general.useragent.vendor", "Linux Mint");
-pref("general.useragent.vendorSub", "17.2");
-pref("general.useragent.vendorComment", "Rafaela");
+pref("general.useragent.vendorSub", "17.3");
+pref("general.useragent.vendorComment", "Rosa");
 
 // Default search engine
 pref("browser.search.searchEnginesURL", "http://www.linuxmint.com/searchengines/");
